//
//  ProfilesViewController.m
//  ProfileViewer
//
//  Created by Ken Anderson on 11/2/11.
//  Copyright (c) 2011 University of Colorado, Boulder. All rights reserved.
//

#import "ProfilesViewController.h"
#import "Profile.h"
#import "ProfileViewController.h"
#import "Profiles.h"

@interface ProfilesViewController ()

@property (nonatomic, strong) Profiles* profiles;

@end

@implementation ProfilesViewController

@synthesize profiles = _profiles;

- (id) initWithStyle:(UITableViewStyle)style {
    return [self init];
}

- (id) init {
    self = [super initWithStyle:UITableViewStyleGrouped];
    
    if (self) {
        
        self.navigationItem.title = @"Profiles";
        self.navigationItem.leftBarButtonItem = self.editButtonItem;
        self.navigationItem.rightBarButtonItem =
            [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self action:@selector(handleAdd:)];
        self.profiles = [[Profiles alloc] init];
    }
    
    return self;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [[self.profiles allProfiles] count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell* cell = [tableView dequeueReusableCellWithIdentifier:@"UITableViewCell"];
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:@"UITableViewCell"];
    }
    
    Profile* p = [[self.profiles allProfiles] objectAtIndex:indexPath.row];
    
    cell.textLabel.text = [p fullName];
    cell.detailTextLabel.text = p.email;
    cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
    
    return cell;
    
}

- (void) handleAdd:(id) sender {
    [self.profiles createProfile];
    [self.tableView reloadData];
}

- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        Profile* p = [[self.profiles allProfiles] objectAtIndex:indexPath.row];
        [self.profiles removeProfile:p];
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:YES];
    }
}

- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)sourceIndexPath toIndexPath:(NSIndexPath *)destinationIndexPath {
    [self.profiles moveProfileAtIndex:sourceIndexPath.row toIndex:destinationIndexPath.row];
}

- (void)viewWillAppear:(BOOL)animated {
    [super viewWillAppear:animated];
    [self.tableView reloadData];
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    ProfileViewController *pvc = [[ProfileViewController alloc] init];
    pvc.profile = [[self.profiles allProfiles] objectAtIndex:indexPath.row];
    [self.navigationController pushViewController:pvc animated:YES];
}

@end
