//
//  Profiles.m
//  ProfileViewer
//
//  Created by Ken Anderson on 11/2/11.
//  Copyright (c) 2011 University of Colorado, Boulder. All rights reserved.
//

#import "Profiles.h"
#import "Profile.h"

@interface Profiles ()

@property (nonatomic, strong) NSMutableArray* profiles;

@end

@implementation Profiles

@synthesize profiles = _profiles;

- (id) init {
    return [super init];
}

- (NSArray*) allProfiles {
    [self loadProfiles];
    return self.profiles;
}

- (Profile*) createProfile {
    [self loadProfiles];
    [self.profiles addObject:[Profile randomProfile]];
    return [self.profiles objectAtIndex:([self.profiles count]-1)];
}

- (void) moveProfileAtIndex:(int)from toIndex:(int)to {
    if (from == to) {
        return;
    }
    
    Profile* p = [self.profiles objectAtIndex:from];
    [self.profiles removeObjectAtIndex:from];
    [self.profiles insertObject:p atIndex:to];
}

- (void) removeProfile:(Profile*) profile {
    [self.profiles removeObjectIdenticalTo:profile];
}

- (NSString*) profilesPath {
    NSArray* directories = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString* dir = [directories objectAtIndex:0];
    return [dir stringByAppendingPathComponent:@"profiles.data"];
}

- (BOOL) saveProfiles {
    if (self.profiles) {
        return [NSKeyedArchiver archiveRootObject:self.profiles toFile:[self profilesPath]];
    }
    return NO;
}

- (void) loadProfiles {
    if (!self.profiles) {
        self.profiles = [NSKeyedUnarchiver unarchiveObjectWithFile:[self profilesPath]];
    }
    if (!self.profiles) {
        self.profiles = [[NSMutableArray alloc] init];
    }
}


@end
